@@ -34,8 +34,8 @@ async def _naifu_draw(event: MessageEvent, args: Namespace = ShellCommandArgs())
 
 
 @naifu_permission.handle()
-async def _operate_permission(args: Namespace = ShellCommandArgs()) -> None:
-    await args.operate(matcher=naifu_permission, user_id=args.uid, group_id=args.gid)
+async def _operate_permission(event: MessageEvent, args: Namespace = ShellCommandArgs()) -> None:
+    await args.operate(matcher=naifu_permission, event=event, user_id=args.uid, group_id=args.gid)
 
 
 @nb_driver.on_shutdown
